@@ -159,42 +159,63 @@ def main():
     parser.set_defaults(execute=lambda args: parser.print_help())
 
     # Declare the sub-parser for the "version" command.
-    subparser_version = subparsers.add_parser("version",
+    subparser_version = subparsers.add_parser(
+        "version",
         description="Show version of pydwf and the the DWF library.",
         help="show version of the DWF library")
     subparser_version.set_defaults(execute=lambda args: show_version())
 
     # Declare the sub-parser for the "list" command.
-    subparser_list = subparsers.add_parser("list", aliases=["ls"],
+
+    subparser_list = subparsers.add_parser(
+        "list",
+        aliases=["ls"],
         description="List Digilent Waveforms devices.",
         help="list Digilent Waveforms devices")
+
     subparser_list.add_argument(
         '-u', '--use-obsolete-api',
         action='store_true',
         help="for each device, print analog-in parameters obtained using obsolete FDwfEnumAnalogIn* API calls",
         dest='use_obsolete_api')
-    subparser_list.add_argument('-c', '--list-configurations', action='store_true',
-                        help="for each device, printing its configurations", dest='list_configurations')
-    subparser_list.set_defaults(execute=lambda args: list_devices(args.use_obsolete_api, args.list_configurations))
+
+    subparser_list.add_argument(
+        '-c', '--list-configurations',
+        action='store_true',
+        help="for each device, printing its configurations", dest='list_configurations')
+
+    subparser_list.set_defaults(
+        execute=lambda args: list_devices(args.use_obsolete_api, args.list_configurations))
 
     # Declare the sub-parser for the "extract-examples" command.
-    subparser_extract_examples = subparsers.add_parser("extract-examples",
+
+    subparser_extract_examples = subparsers.add_parser(
+        "extract-examples",
         description="Extract pydwf example scripts to 'pydwf-examples' directory.",
         help="extract pydwf example scripts to 'pydwf-examples' directory")
-    subparser_extract_examples.set_defaults(execute=lambda args:  extract_zipfile("examples", "pydwf-examples"))
+
+    subparser_extract_examples.set_defaults(
+        execute=lambda args:  extract_zipfile("examples", "pydwf-examples"))
 
     # Declare the sub-parser for the "extract-html-docs" command.
-    subparser_extract_html = subparsers.add_parser("extract-html-docs",
+
+    subparser_extract_html = subparsers.add_parser(
+        "extract-html-docs",
         description="Extract pydwf HTML documentation to 'pydwf-html-docs' directory.",
         help="extract pydwf HTML documentation to 'pydwf-html-docs' directory")
-    subparser_extract_html.set_defaults(execute=lambda args: extract_zipfile("html_docs", "pydwf-html-docs"))
+
+    subparser_extract_html.set_defaults(
+        execute=lambda args: extract_zipfile("html_docs", "pydwf-html-docs"))
 
     # Declare the sub-parser for the "extract-html-docs" command.
-    subparser_extract_pdf = subparsers.add_parser("extract-pdf-manual",
+
+    subparser_extract_pdf = subparsers.add_parser(
+        "extract-pdf-manual",
         description="Extract pydwf PDF manual in current directory.",
         help="extract pydwf PDF manual in current directory")
-    subparser_extract_pdf.set_defaults(execute=lambda args:
-                                       extract_zipfile("pdf_manual", "pydwf-{}.pdf".format(pydwf.__version__)))
+
+    subparser_extract_pdf.set_defaults(
+        execute=lambda args: extract_zipfile("pdf_manual", "pydwf-{}.pdf".format(pydwf.__version__)))
 
     # Parse command-line arguments.
     args = parser.parse_args()
