@@ -675,9 +675,9 @@ class AnalogIn(DwfDevice_SubAPI):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
         acquisition_mode_bitset = c_acquisition_mode_bitset.value
-        acquisiton_mode_list = [acquisiton_mode for acquisiton_mode in DwfAcquisitionMode
-                                if acquisition_mode_bitset & (1 << acquisiton_mode.value)]
-        return acquisiton_mode_list
+        acquisition_mode_list = [acquisition_mode for acquisition_mode in DwfAcquisitionMode
+                                 if acquisition_mode_bitset & (1 << acquisition_mode.value)]
+        return acquisition_mode_list
 
     def acquisitionModeSet(self, acquisition_mode: DwfAcquisitionMode) -> None:
         """Set the acquisition mode.
@@ -1168,25 +1168,25 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while retrieving the trigger position info.
         """
-        c_secMin = typespec_ctypes.c_double()
-        c_secMax = typespec_ctypes.c_double()
-        c_nSteps = typespec_ctypes.c_double()
+        c_trigger_position_min = typespec_ctypes.c_double()
+        c_trigger_position_max = typespec_ctypes.c_double()
+        c_trigger_position_num_steps = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogInTriggerPositionInfo(
             self.hdwf,
-            c_secMin,
-            c_secMax,
-            c_nSteps)
+            c_trigger_position_min,
+            c_trigger_position_max,
+            c_trigger_position_num_steps)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-        if not c_nSteps.value.is_integer():
+        if not c_trigger_position_num_steps.value.is_integer():
             raise PyDwfError("Bad number of steps received.")
 
-        secMin = c_secMin.value
-        secMax = c_secMax.value
-        nSteps = int(c_nSteps.value)
+        trigger_position_min = c_trigger_position_min.value
+        trigger_position_max = c_trigger_position_max.value
+        trigger_position_num_steps = int(c_trigger_position_num_steps.value)
 
-        return (secMin, secMax, nSteps)
+        return (trigger_position_min, trigger_position_max, trigger_position_num_steps)
 
     def triggerPositionSet(self, trigger_position: float) -> None:
         """Set the trigger position.
@@ -1218,12 +1218,12 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the trigger position setpoint.
         """
-        c_secPosition = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogInTriggerPositionGet(self.hdwf, c_secPosition)
+        c_trigger_position = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogInTriggerPositionGet(self.hdwf, c_trigger_position)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        secPosition = c_secPosition.value
-        return secPosition
+        trigger_position = c_trigger_position.value
+        return trigger_position
 
     def triggerPositionStatus(self) -> float:
         """Get the current trigger position status.
@@ -1234,12 +1234,12 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the trigger position status.
         """
-        c_secPosition = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogInTriggerPositionStatus(self.hdwf, c_secPosition)
+        c_trigger_position = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogInTriggerPositionStatus(self.hdwf, c_trigger_position)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        secPosition = c_secPosition.value
-        return secPosition
+        trigger_position = c_trigger_position.value
+        return trigger_position
 
     def triggerAutoTimeoutInfo(self) -> Tuple[float, float, int]:
         """Get trigger auto-timeout info.
@@ -1262,7 +1262,7 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
         if not c_nSteps.value.is_integer():
-            raise PyDwfError("Bad autotimeout info number of steps.")
+            raise PyDwfError("Bad auto-timeout info number of steps.")
 
         secMin = c_secMin.value
         secMax = c_secMax.value
@@ -1405,9 +1405,11 @@ class AnalogIn(DwfDevice_SubAPI):
         return trigger_type
 
     def triggerChannelInfo(self) -> Tuple[int, int]:
-        """Get trigger channel info.
+        """Get |AnalogIn| trigger detector channel info.
 
         The |AnalogIn| trigger detector is sensitive to a specific channel.
+        This method returns the range of valid analog input channels that can be configured
+        as the |AnalogIn| trigger detector channel.
 
         Returns:
             Tuple[int, int]: A two-element tuple (min_channel_index, max_channel_index).
@@ -1428,7 +1430,9 @@ class AnalogIn(DwfDevice_SubAPI):
         return (trigger_channel_index_min, trigger_channel_index_max)
 
     def triggerChannelSet(self, trigger_channel_index: int) -> None:
-        """Set trigger channel.
+        """Set |AnalogIn| trigger detector channel.
+
+        This is the analog input channel that the |AnalogIn| trigger detector is sensitive to.
 
         Parameters:
             trigger_channel_index (int): The trigger channel to be selected.
@@ -1441,7 +1445,9 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def triggerChannelGet(self) -> int:
-        """Get trigger channel.
+        """Get |AnalogIn| trigger detector channel.
+
+        This is the analog input channel that the |AnalogIn| trigger detector is sensitive to.
 
         Returns:
             int: The currently configured trigger channel.
@@ -1475,7 +1481,7 @@ class AnalogIn(DwfDevice_SubAPI):
         return trigger_filter_list
 
     def triggerFilterSet(self, trigger_filter: DwfAnalogInFilter) -> None:
-        """Set trigger filter.
+        """Set |AnalogIn| trigger detector filter.
 
         Parameters:
             trigger_filter (DwfAnalogInFilter): The trigger filter to be selected.
@@ -1488,7 +1494,7 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def triggerFilterGet(self) -> DwfAnalogInFilter:
-        """Get trigger filter.
+        """Get |AnalogIn| trigger detector filter.
 
         Returns:
             int: The currently configured trigger filter.
@@ -1504,7 +1510,7 @@ class AnalogIn(DwfDevice_SubAPI):
         return trigger_filter
 
     def triggerLevelInfo(self) -> Tuple[float, float, int]:
-        """Get trigger level info.
+        """Get |AnalogIn| trigger detector level info, in Volts.
 
         Returns:
             Tuple[float, float, int]: The valid range of trigger level values that can be configured.
@@ -1530,7 +1536,7 @@ class AnalogIn(DwfDevice_SubAPI):
         return (voltsMin, voltsMax, nSteps)
 
     def triggerLevelSet(self, trigger_level: float) -> None:
-        """Set trigger level.
+        """Set |AnalogIn| trigger detector level, in Volts.
 
         Parameters:
             trigger_level (float): The trigger level to be configured, in Volts.
@@ -1543,10 +1549,10 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def triggerLevelGet(self) -> float:
-        """Get trigger level.
+        """Get |AnalogIn| trigger detector level, in Volts.
 
         Returns:
-            int: The currently configured trigger level, in Volts.
+            float: The currently configured trigger level, in Volts.
 
         Raises:
             DwfLibraryError: There was an error while getting the trigger level.
@@ -1559,37 +1565,37 @@ class AnalogIn(DwfDevice_SubAPI):
         return trigger_level
 
     def triggerHysteresisInfo(self) -> Tuple[float, float, int]:
-        """Get trigger hysteresis info.
+        """Get |AnalogIn| trigger detector hysteresis info, in Volts.
 
         Returns:
-            Tuple[float, float, int]: Rhe valid range of trigger hysteresis values that can be configured.
+            Tuple[float, float, int]: The valid range of trigger hysteresis values that can be configured.
 
         Raises:
             DwfLibraryError: There was an error while getting the trigger hysteresis info.
         """
-        c_voltsMin = typespec_ctypes.c_double()
-        c_voltsMax = typespec_ctypes.c_double()
-        c_nSteps = typespec_ctypes.c_double()
+        c_trigger_hysteresis_min = typespec_ctypes.c_double()
+        c_trigger_hysteresis_max = typespec_ctypes.c_double()
+        c_trigger_hysteresis_num_steps = typespec_ctypes.c_double()
 
         result = self.lib.FDwfAnalogInTriggerHysteresisInfo(
             self.hdwf,
-            c_voltsMin,
-            c_voltsMax,
-            c_nSteps)
+            c_trigger_hysteresis_min,
+            c_trigger_hysteresis_max,
+            c_trigger_hysteresis_num_steps)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-        if not c_nSteps.value.is_integer():
+        if not c_trigger_hysteresis_num_steps.value.is_integer():
             raise PyDwfError("Bad trigger hysteresis info number of steps.")
 
-        voltsMin = c_voltsMin.value
-        voltsMax = c_voltsMax.value
-        nSteps = int(c_nSteps.value)
+        trigger_hysteresis_min = c_trigger_hysteresis_min.value
+        trigger_hysteresis_max = c_trigger_hysteresis_max.value
+        trigger_hysteresis_num_steps = int(c_trigger_hysteresis_num_steps.value)
 
-        return (voltsMin, voltsMax, nSteps)
+        return (trigger_hysteresis_min, trigger_hysteresis_max, trigger_hysteresis_num_steps)
 
     def triggerHysteresisSet(self, trigger_hysteresis: float) -> None:
-        """Set trigger hysteresis.
+        """Set |AnalogIn| trigger detector hysteresis, in Volts.
 
         Parameters:
             trigger_hysteresis (float): The trigger hysteresis to be configured, in Volts.
@@ -1602,10 +1608,10 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def triggerHysteresisGet(self) -> float:
-        """Get trigger hysteresis.
+        """Get |AnalogIn| trigger detector trigger hysteresis, in Volts.
 
         Returns:
-            int: The currently configured trigger hysteresis, in Volts.
+            float: The currently configured trigger hysteresis, in Volts.
 
         Raises:
             DwfLibraryError: There was an error while getting the trigger hysteresis.
@@ -1618,7 +1624,7 @@ class AnalogIn(DwfDevice_SubAPI):
         return trigger_hysteresis
 
     def triggerConditionInfo(self) -> List[DwfTriggerSlope]:
-        """Get trigger condition info.
+        """Get |AnalogIn| trigger detector condition info.
 
         Raises:
             DwfLibraryError: There was an error while getting the trigger condition info.
@@ -1635,7 +1641,7 @@ class AnalogIn(DwfDevice_SubAPI):
         return trigger_condition_list
 
     def triggerConditionSet(self, trigger_condition: DwfTriggerSlope) -> None:
-        """Set trigger condition.
+        """Set |AnalogIn| trigger detector condition.
 
         Parameters:
             trigger_condition (DwfTriggerSlope): The trigger condition to be configured.
@@ -1648,7 +1654,7 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def triggerConditionGet(self) -> DwfTriggerSlope:
-        """Get trigger condition.
+        """Get |AnalogIn| trigger detector condition.
 
         Returns:
             DwfTriggerSlope: The currently configured trigger condition.
@@ -1664,7 +1670,7 @@ class AnalogIn(DwfDevice_SubAPI):
         return DwfTriggerSlope(trigger_condition)
 
     def triggerLengthInfo(self) -> Tuple[float, float, int]:
-        """Get trigger length info.
+        """Get |AnalogIn| trigger detector length info, in seconds.
 
         Returns:
             Tuple[float, float, int]: The valid range of trigger length values that can be configured.
@@ -1672,25 +1678,26 @@ class AnalogIn(DwfDevice_SubAPI):
         Raises:
             DwfLibraryError: There was an error while getting the trigger length info.
         """
-        c_secMin = typespec_ctypes.c_double()
-        c_secMax = typespec_ctypes.c_double()
-        c_nSteps = typespec_ctypes.c_double()
+        c_trigger_length_min = typespec_ctypes.c_double()
+        c_trigger_length_max = typespec_ctypes.c_double()
+        c_trigger_length_num_steps = typespec_ctypes.c_double()
 
-        result = self.lib.FDwfAnalogInTriggerLengthInfo(self.hdwf, c_secMin, c_secMax, c_nSteps)
+        result = self.lib.FDwfAnalogInTriggerLengthInfo(self.hdwf, c_trigger_length_min, c_trigger_length_max,
+                                                        c_trigger_length_num_steps)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-        if not c_nSteps.value.is_integer():
+        if not c_trigger_length_num_steps.value.is_integer():
             raise PyDwfError("Bad trigger length info number of steps.")
 
-        secMin = c_secMin.value
-        secMax = c_secMax.value
-        nSteps = int(c_nSteps.value)
+        trigger_length_min = c_trigger_length_min.value
+        trigger_length_max = c_trigger_length_max.value
+        trigger_length_num_steps = int(c_trigger_length_num_steps.value)
 
-        return (secMin, secMax, nSteps)
+        return (trigger_length_min, trigger_length_max, trigger_length_num_steps)
 
     def triggerLengthSet(self, trigger_length: float) -> None:
-        """Set trigger length.
+        """Set |AnalogIn| trigger detector length, in seconds.
 
         Parameters:
             trigger_length (float): The trigger length to be configured, in seconds.
@@ -1703,7 +1710,7 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def triggerLengthGet(self) -> float:
-        """Get trigger length.
+        """Get |AnalogIn| trigger detector length, in seconds.
 
         Returns:
             float: The currently configured trigger length, in seconds.
@@ -1719,7 +1726,7 @@ class AnalogIn(DwfDevice_SubAPI):
         return trigger_length
 
     def triggerLengthConditionInfo(self) -> List[DwfTriggerLength]:
-        """Get trigger length condition info.
+        """Get |AnalogIn| trigger detector length condition info.
 
         Returns:
             List[DwfTriggerLength]: The valid trigger length condition values that can be selected.
@@ -1736,7 +1743,7 @@ class AnalogIn(DwfDevice_SubAPI):
         return triglen_list
 
     def triggerLengthConditionSet(self, trigger_length_condition: DwfTriggerLength) -> None:
-        """Set trigger length condition.
+        """Set |AnalogIn| trigger detector length condition.
 
         Parameters:
             trigger_length_condition (DwfTriggerLength): The trigger length condition to be configured.
@@ -1751,7 +1758,7 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def triggerLengthConditionGet(self) -> DwfTriggerLength:
-        """Get trigger length condition.
+        """Get |AnalogIn| trigger detector length condition.
 
         Returns:
             DwfTriggerLength: The currently configured trigger length condition.
@@ -1769,7 +1776,7 @@ class AnalogIn(DwfDevice_SubAPI):
         return trigger_length_condition
 
     def samplingSourceSet(self, sampling_source: DwfTriggerSource) -> None:
-        """Set sampling source.
+        """Set |AnalogIn| sampling source.
 
         Parameters:
             sampling_source (DwfTriggerSource): The sampling source to be configured.
@@ -1782,7 +1789,7 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def samplingSourceGet(self) -> DwfTriggerSource:
-        """Get sampling source.
+        """Get |AnalogIn| sampling source.
 
         Returns:
             DwfTriggerSource: The currently configured sampling source.
@@ -1798,7 +1805,7 @@ class AnalogIn(DwfDevice_SubAPI):
         return sampling_source
 
     def samplingSlopeSet(self, sampling_slope: DwfTriggerSlope) -> None:
-        """Set sampling slope.
+        """Set |AnalogIn| sampling slope.
 
         Parameters:
             sampling_slope (DwfTriggerSlope): The sampling slope to be configured.
@@ -1811,7 +1818,7 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def samplingSlopeGet(self) -> DwfTriggerSlope:
-        """Get sampling slope.
+        """Get |AnalogIn| sampling slope.
 
         Returns:
             DwfTriggerSlope: The currently configured sampling slope.
@@ -1827,7 +1834,7 @@ class AnalogIn(DwfDevice_SubAPI):
         return sampling_slope
 
     def samplingDelaySet(self, sampling_delay: float) -> None:
-        """Set sampling delay.
+        """Set |AnalogIn| sampling delay.
 
         Parameters:
             sampling_delay (float): The sampling delay to be configured, in seconds.
@@ -1840,7 +1847,7 @@ class AnalogIn(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def samplingDelayGet(self) -> float:
-        """Get sampling delay.
+        """Get |AnalogIn| sampling delay.
 
         Returns:
             float: The currently configured sampling delay, in seconds.
