@@ -827,7 +827,7 @@ class DwfAnalogImpedance(enum.Enum):
     AdmittancePhase     =  5  # Radians
     Conductance         =  6  # Siemens
     Susceptance         =  7  # Siemens
-    SeriesCapactance    =  8  # Farad
+    SeriesCapacitance   =  8  # Farad
     ParallelCapacitance =  9  # Farad
     SeriesInductance    = 10  # Henry
     ParallelInductance  = 11  # Henry
@@ -885,7 +885,7 @@ class DwfParameter(enum.Enum):
     """
 
     AudioOut = 5
-    """Enable or disable audo output.
+    """Enable or disable audio output.
 
     Possible values:
 
