@@ -36,7 +36,9 @@ class DwfDevice:
 
     The main test and measurement functionality of a Digilent Waveforms device is provided as
     multiple sub-interfaces (instruments, protocols, and measurements). To access those,
-    use one of the eleven attributes described below:
+    use one of the eleven attributes described below.
+
+    .. rubric:: |DwfDevice| attributes
 
     Attributes:
 
@@ -46,22 +48,24 @@ class DwfDevice:
             Provides access to the analog output (waveform generator) functionality.
         analogIO (AnalogIO):
             Provides access to the analog I/O (voltage source, monitoring) functionality.
-        digitalIO (DigitalIO):
-            Provides access to the static digital I/O functionality.
+        analogImpedance (AnalogImpedance):
+            Provides access to the analog impedance measurement functionality.
         digitalIn (DigitalIn):
             Provides access to the dynamic digital input (logic analyzer) functionality.
         digitalOut (DigitalOut):
             Provides access to the dynamic digital output (pattern generator) functionality.
+        digitalIO (DigitalIO):
+            Provides access to the static digital I/O functionality.
         digitalUart (DigitalUart):
             Provides access to the UART protocol functionality.
+        digitalCan (DigitalCan):
+            Provides access to the CAN protocol functionality.
         digitalSpi (DigitalSpi):
             Provides access to the SPI protocol functionality.
         digitalI2c (DigitalI2c):
             Provides access to the I2C protocol functionality.
-        digitalCan (DigitalCan):
-            Provides access to the CAN protocol functionality.
-        analogImpedance (AnalogImpedance):
-            Provides access to the analog impedance measurement functionality.
+
+    .. rubric:: |DwfDevice| methods
     """
 
     # pylint: disable=too-many-instance-attributes
@@ -70,7 +74,7 @@ class DwfDevice:
         """Initialize a DwfDevice with the specified DWF handle value.
 
         This method is used by the |DwfLibrary.device.open| method to initialize a |DwfDevice| immediately after
-        succesfully opening a Digilent Waveforms device using the low-level C API.
+        successfully opening a Digilent Waveforms device using the low-level C API.
 
         User programs should not initialize |DwfDevice| instances themselves, but leave that to |pydwf| instead.
 
@@ -89,14 +93,14 @@ class DwfDevice:
         self.analogIn = AnalogIn(self)
         self.analogOut = AnalogOut(self)
         self.analogIO = AnalogIO(self)
-        self.digitalIO = DigitalIO(self)
+        self.analogImpedance = AnalogImpedance(self)
         self.digitalIn = DigitalIn(self)
         self.digitalOut = DigitalOut(self)
+        self.digitalIO = DigitalIO(self)
         self.digitalUart = DigitalUart(self)
         self.digitalCan = DigitalCan(self)
         self.digitalSpi = DigitalSpi(self)
         self.digitalI2c = DigitalI2c(self)
-        self.analogImpedance = AnalogImpedance(self)
 
     def __enter__(self):
         """Context manager entry method."""
