@@ -30,7 +30,7 @@ class DwfLibrary:
     def __init__(self, check_library_version: bool = True) -> None:
         """Initialize a |DwfLibrary| instance.
 
-        This method instantiates a |ctypes| shared library, type-annotates its functions, and initializes the
+        This method instantiates a |ctypes:link| shared library, type-annotates its functions, and initializes the
         |deviceEnum:link| and |deviceControl:link| attributes that provide access to |device enumeration:link| and
         |device control:link| functionality.
 
@@ -73,7 +73,7 @@ class DwfLibrary:
 
     @property
     def lib(self) -> ctypes.CDLL:
-        """Return the |ctypes| shared library instance used to access the DWF library.
+        """Return the |ctypes:link| shared library instance used to access the DWF library.
 
         This property is primarily provided for internal |pydwf| use.
 
@@ -83,7 +83,8 @@ class DwfLibrary:
 
     @staticmethod
     def _annotate_function_signatures(lib: ctypes.CDLL) -> None:
-        """Add |ctypes| return type and parameter type annotations for all known functions in the DWF shared library.
+        """Add |ctypes:link| return type and parameter type annotations for all known functions in the DWF
+        shared library.
 
         This function uses a list of DWF function signatures derived from the *dwf.h* C header file to perform
         the type annotation.
